# Generated by Django 5.2 on 2025-04-20 14:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_solomon', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='magiclink',
            name='ip_address',
            field=models.GenericIPAddressField(blank=True, null=True, verbose_name='IP Address'),
        ),
    ]
